<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:stsuuser="urn:ibm:names:ITFIM:1.0:stsuuser" version="1.0">
	<xsl:strip-space elements="*" />
	<xsl:output method="xml" version="1.0" encoding="utf-8"
		indent="yes" />
		
	<!-- 
		Initially we start with a copy of the document. 
	-->
	<xsl:template match="@* | node()">
		<xsl:copy>
			<xsl:apply-templates select="@* | node()" />
		</xsl:copy>
	</xsl:template>
	
	<!-- 
		Note: No Principal template is necessary for identity provider on SAML 2.0 since name identifiers
		will be carried in the Subject element of the assertion. 
	-->
	
	<!-- 
		This template builds a new AttributeList. This involves: 
		a) Adding an AuthnContextClassRef attribute to meet SAML requirements. We assume this is 
		   always the "password" mechanism, regardless of what the TAM credential actually says. 
		b) Map the tagvalue_name to commonName 
		c) Map the tagvalue_ssn to ssn 
		d) Add an Attribute to the AttributeList with name "role" and a value for each of the 
		groups the user is in.
	-->
	<xsl:template match="//stsuuser:AttributeList">
		<stsuuser:AttributeList>
		
			<!-- First the authentcation context class ref. attribute -->
            <stsuuser:Attribute name="AuthnContextClassRef" type="urn:oasis:names:tc:SAML:2.0:assertion">
                 <stsuuser:Value>urn:oasis:names:tc:SAML:2.0:ac:classes:Password</stsuuser:Value>
            </stsuuser:Attribute>

			
			<!-- Now the commonName attribute -->
			<stsuuser:Attribute name="commonName"
				type="http://example.com/federation/v1/commonName">
				<stsuuser:Value><xsl:value-of
						select="//stsuuser:AttributeList/stsuuser:Attribute[@name='tagvalue_name'][@type='urn:ibm:names:ITFIM:5.1:accessmanager']/stsuuser:Value" /></stsuuser:Value>
			</stsuuser:Attribute>
			
			<!-- Now the ssn attribute -->
			<stsuuser:Attribute name="ssn"
				type="http://example.com/federation/v1/ssn">
				<stsuuser:Value><xsl:value-of
						select="//stsuuser:AttributeList/stsuuser:Attribute[@name='tagvalue_ssn'][@type='urn:ibm:names:ITFIM:5.1:accessmanager']/stsuuser:Value" /></stsuuser:Value>
			</stsuuser:Attribute>

			<!-- Now the email attribute -->
			<stsuuser:Attribute name="email" type="http://example.com/federation/v1/email">
				<stsuuser:Value>
					<xsl:value-of select="//stsuuser:AttributeList/stsuuser:Attribute[@name='tagvalue_email'][@type='urn:ibm:names:ITFIM:5.1:accessmanager']/stsuuser:Value" />
				</stsuuser:Value>
			</stsuuser:Attribute>			
			
			<!-- Now the role attribute (can be multi-valued) -->
			<stsuuser:Attribute name="role"
				type="http://example.com/federation/v1/role">
				<xsl:for-each
					select="//stsuuser:GroupList/stsuuser:Group">
					<stsuuser:Value><xsl:value-of select="@name" /></stsuuser:Value>
				</xsl:for-each>
			</stsuuser:Attribute>			
		</stsuuser:AttributeList>
	</xsl:template>
</xsl:stylesheet>
